/**
 * This builder implements a fast and compact DAWG data-structure (a.k.a.:
 * direct acyclic word graph, with suffix and prefix compression of the
 * top-level domains) using JavaScript Objects. It is a good trade-off between
 * correctness, speed and space. This is much faster then using a linear scan
 * over all the rules, but slightly slower than the probabilistic
 * data-structure implemented in `bin/builders/hashes.js`.
 *
 * Here is a simple example:
 *
 *   co.uk
 *   gov.uk
 *   fr
 *
 *  <root>
 *    |_ uk
 *       |_ co *
 *       |_ gov *
 *    |_ fr *
 *
 *  Finding a match is then a matter of iterating on labels of a hostname
 *  backward and following the branches of the Trie. Whenever we find a terminal
 *  node (indicated with a '*' above), we consider this a match.
 */
declare const _default: (body: string, { includePrivate }: {
    includePrivate: boolean;
}) => string;
export default _default;
